@@ -64,7 +64,7 @@ class SimpleMySQLdb(SimpleDB):
             return cursor
         except _mysql_exceptions.OperationalError:
             if not kwargs['reconnect']:
-                raise _mysql_exceptions.OperationalError
+                raise
             try:
                 self.dbh.close()
             except Exception:
